;----------------------------------------------------------------------------
;  Funktionen zum ansteuern eines parallelen LCD-Displays
;----------------------------------------------------------------------------
;       F_LCD_init:     mu zuerst aufgerufen werden
;       F_LCD_clear:    lsche Bildschirm
;       F_LCD_printbd:   Ausgabe eines Bytes als Zahl (ACC, dezimal)
;       F_LCD_printc:   Ausgabe eines Bytes als Char (ACC)
;       F_LCD_prints:   Ausgabe eines Strings (DPTR, Nullterminiert)
;----------------------------------------------------------------------------
; bentigt werden:
;  - time.inc
;  - ein Byte RAM       LCD_RAM
;  - Pin Enable         ENABLE
;  - Pin RS             RS      
;  - Pin R/W            RW      
;  - Port fr Daten     DATEN   
;----------------------------------------------------------------------------
F_LCD_clear:
        push ACC
        mov a,#1
        acall F_LCD_send_b
        mov LCD_RAM,#0
        pop ACC
        ret
;- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
F_LCD_init:
; LCD initialisieren
        push ACC
; 1.: einige ms warten, bis sich der Spannungspegel stabilisiert hat
        mov a,#10
        acall F_wait_m
        clr RS
        clr RW
        clr ENABLE
        mov a,#38h
        acall F_LCD_send_b
        mov a,#1100b
        acall F_LCD_send_b
        mov a,#00111100b
        acall F_LCD_send_b
        acall F_LCD_clear
        pop ACC
        ret
;- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
F_LCD_printc:
; ausgabe eines Charakters aus ACC (bentigt ein Byte RAM - LCD_RAM)
; ist der Spalt im RAM erreicht?
        push ACC
        inc LCD_RAM
        mov a,LCD_RAM
        clr c
        subb a,#9
        jnz F_LCD_printc_weiter
; RAM weitersetzen
        mov a,#128+40
        acall F_LCD_send_b
F_LCD_printc_weiter:
        pop ACC
; Zeichen ausgeben
        acall F_LCD_send_d
        ret                
;- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
F_LCD_printbd:
; ausgabe eines Bytes als Zahl
        push ACC
        push 0
        push B
        mov B,#100
        div AB
        add a,#30h
        acall F_LCD_printc
        mov a,B
        mov B,#10
        div AB
        add a,#30h
        acall F_LCD_printc
        mov a,B
        add a,#30h
        acall F_LCD_printc


        pop B
        pop 0
        pop ACC
        ret                

;- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
F_LCD_prints:
; ausgabe eines mit 0 terminierten Strings aus DPTR
        push ACC
        push 0
        mov R0,#0
F_LCD_prints_anf:
        mov a,R0
        movc a,@A+DPTR
        jz F_LCD_prints_weiter
        inc R0
        acall F_LCD_printc

        mov a,R0
        subb a,#16
        jnz F_LCD_prints_anf

F_LCD_prints_weiter:
        pop 0
        pop ACC
        ret                
;- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
F_LCD_send_b:
;sendet Befehle aus ACC an DATEN
        clr RS
        clr RW
        ajmp F_LCD_send
;- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
F_LCD_send_d:
;sendet Daten aus ACC an DATEN
        clr RW
        setb RS
F_LCD_send:
        mov DATEN,a
        setb ENABLE
        push ACC
        mov a,#2
        acall F_wait_m
        pop ACC
        clr ENABLE
        ret
;- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
